@@ -5,7 +5,7 @@ function(x,para) {
     XI <- para$para[1]
     A  <- para$para[2]
 
-    f <- vector(mode="numeric")
+    f <- vector(mode="numeric", length=length(x))
     for(i in seq(1,length(x))) {
       my.x  <- x[i]
       Y <- (my.x - XI)/A
