@@ -4,7 +4,7 @@ function(x,para) {
    U <- para$para[1] 
    A <- para$para[2] 
 
-   f <- vector(mode="numeric")
+   f <- vector(mode="numeric", length=length(x))
    for(i in seq(1,length(x))) {
      f[i] = 1 - exp(-1*(x[i] - U)^2/(2*A^2))
    }
