@@ -34,7 +34,7 @@ function(x,wakpara) {
     C  <- wakpara$para[4]
     D  <- wakpara$para[5]
 
-    f <- vector(mode="numeric")
+    f <- vector(mode="numeric", length=length(x))
     for(i in seq(1,length(x))) {
       if(x[i] <= XI) { f[i] <- 0; next }
       #
