@@ -4,7 +4,7 @@ function(x,para) {
     U <- para$para[1]
     A <- para$para[2]
 
-    f <- vector(mode="numeric")
+    f <- vector(mode="numeric", length=length(x))
     for(i in seq(1,length(x))) {
       Y <- (x[i]-U)/A
       if(Y <= 0) {
