@@ -12,7 +12,7 @@ function(x,gldpara,paracheck=TRUE) {
     L3 <- gldpara$para[3]
     L4 <- gldpara$para[4]
 
-    f <- vector(mode="numeric")
+    f <- vector(mode="numeric", length=length(x))
     for(i in seq(1,length(x))) {
       F <- cdfgld(x[i],gldpara,paracheck=FALSE)
       f[i] <- 1/((L3*F^(L3-1) + L4*(1-F)^(L4-1))*L2)
