@@ -8,9 +8,8 @@ function(f,para,paracheck=TRUE) {
     XI <- para$para[1] 
     A  <- para$para[2] 
     K  <- para$para[3]
-    n <- length(f)
-    x <- vector(mode="numeric",length=n)
-    for(i in seq(1,n)) {
+    x <- vector(mode="numeric", length=length(f))
+    for(i in seq(1,length(f))) {
       if(f[i] == 0 & K < 0) { x[i] <- XI+A/K; next }
       if(f[i] == 1 & K > 0) { x[i] <- XI+A/K; next }
       Y <- qnorm(f[i])
