@@ -6,9 +6,8 @@ function(f,para,paracheck=TRUE) {
    }
    U <- para$para[1] 
    A <- para$para[2] 
-   n <- length(f)
-   x <- vector(mode="numeric",length=n)
-   for(i in seq(1,n)) {
+   x <- vector(mode="numeric", length=length(f))
+   for(i in seq(1,length(f))) {
      x[i] <- U-A*log(-log(f[i]))
    }
   return(x)
