@@ -6,9 +6,8 @@ function(f,para,paracheck=TRUE) {
    }
    A <- para$para[1] 
    B <- para$para[2] 
-   n <- length(f)
-   x <- vector(mode="numeric",length=n)
-   for(i in seq(1,n)) {
+   x <- vector(mode="numeric", length=length(f))
+   for(i in seq(1,length(f))) {
      x[i] <- (1 - (1-f[i])^(1/B))^(1/A)
    }
   return(x)
