@@ -7,9 +7,8 @@ function(f,para,paracheck=TRUE) {
     XI <- para$para[1]
     A  <- para$para[2]
 
-    n <- length(f)
-    x <- vector(mode="numeric",length=n)
-    for(i in seq(1,n)) {
+    x <- vector(mode="numeric", length=length(f))
+    for(i in seq(1,length(f))) {
       my.f <- f[i]
       if(my.f <= 0.5) {
         x[i] <- XI + A * log(2*my.f)
