@@ -10,9 +10,8 @@ function(f,para,paracheck=TRUE) {
     U <- para$para[1]
     A <- para$para[2]
     GAMMA <- para$para[3]
-    n <- length(f)
-    x <- vector(mode="numeric",length=n)
-    for(i in seq(1,n)) {
+    x <- vector(mode="numeric", length=length(f))
+    for(i in seq(1,length(f))) {
       if((f[i] == 0 && GAMMA > 0) ||
          (f[i] == 1 && GAMMA < 0)) {
         x[i] <- U-2*A/GAMMA
