@@ -5,15 +5,14 @@ function(f,para,paracheck=TRUE) {
       if(! are.partexp.valid(para)) return()
     }
 
-    n <- length(f)
-    x <- vector(mode="numeric",length=n)
+    x <- vector(mode="numeric", length=length(f))
 
     U <- para$para[1]
     B <- 1/para$para[2]
     S <- para$para[3]
 
     if(S) { # stationary
-       for(i in seq(1,n)) {
+       for(i in seq(1,length(f))) {
          x[i] <- S*f[i]
        }
        return(x)
@@ -21,7 +20,7 @@ function(f,para,paracheck=TRUE) {
        return(qexp(f, rate=B))
     } else {
        BU <- 1 - exp(-B*U)
-       for(i in seq(1,n)) {
+       for(i in seq(1,length(f))) {
          x[i] <- - log(1 - f[i]*BU) / B
        }
        x[! is.finite(x)] <- - log(.Machine$double.eps) / B
